@@ -129,7 +129,6 @@ use serde_json::value::RawValue as RawJsonValue;
 use self::room::redaction::SyncRedactionEvent;
 
 mod enums;
-mod error;
 mod event_kinds;
 
 // Hack to allow both ruma-events itself and external crates (or tests) to use procedural macros
@@ -186,11 +185,7 @@ pub mod typing;
 #[cfg(feature = "unstable-pre-spec")]
 #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
 pub use self::relation::Relations;
-pub use self::{
-    enums::*,
-    error::{FromStrError, InvalidInput},
-    event_kinds::*,
-};
+pub use self::{enums::*, event_kinds::*};
 
 /// Extra information about an event that is not incorporated into the event's
 /// hash.
@@ -363,10 +358,62 @@ pub trait RedactedMessageEventContent: RedactedEventContent {}
 /// Marker trait for the content of a redacted state event.
 pub trait RedactedStateEventContent: RedactedEventContent {}
 
+/// Trait for abstracting over event content structs.
+///
+/// … but *not* enums which don't always have an event type and kind (e.g. message vs state) that's
+/// fixed / known at compile time.
+pub trait StaticEventContent: EventContent {
+    /// The event's "kind".
+    ///
+    /// See the type's documentation.
+    const KIND: EventKind;
+
+    /// The event type.
+    const TYPE: &'static str;
+}
+
+/// The "kind" of an event.
+///
+/// This corresponds directly to the event content marker traits.
+#[derive(Clone, Copy, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
+#[non_exhaustive]
+pub enum EventKind {
+    /// Global account data event kind.
+    GlobalAccountData,
+
+    /// Room account data event kind.
+    RoomAccountData,
+
+    /// Ephemeral room event kind.
+    EphemeralRoomData,
+
+    /// Message event kind.
+    ///
+    /// Since redacted / non-redacted message events are used in the same places bu have different
+    /// sets of fields, these two variations are treated as two closely-related event kinds.
+    Message {
+        /// Redacted variation?
+        redacted: bool,
+    },
+
+    /// State event kind.
+    ///
+    /// Since redacted / non-redacted state events are used in the same places bu have different
+    /// sets of fields, these two variations are treated as two closely-related event kinds.
+    State {
+        /// Redacted variation?
+        redacted: bool,
+    },
+
+    /// To-device event kind.
+    ToDevice,
+}
+
 /// `HasDeserializeFields` is used in the code generated by the `Event` derive
 /// to aid in deserializing redacted events.
 #[doc(hidden)]
 #[derive(Debug)]
+#[allow(clippy::exhaustive_enums)]
 pub enum HasDeserializeFields {
     /// Deserialize the event's content, failing if invalid.
     True,
