@@ -27,8 +27,12 @@ impl JoinRulesEventContent {
 }
 
 /// The rule used for users wishing to join this room.
+///
+/// This type can hold an arbitrary string. To check for formats that are not available as a
+/// documented variant here, use its string representation, obtained through `.as_str()`.
 #[derive(Clone, Debug, PartialEq, Eq, StringEnum)]
 #[ruma_enum(rename_all = "lowercase")]
+#[non_exhaustive]
 pub enum JoinRule {
     /// A user who wishes to join the room must first receive an invite to the room from someone
     /// already inside of the room.
@@ -46,3 +50,10 @@ pub enum JoinRule {
     #[doc(hidden)]
     _Custom(String),
 }
+
+impl JoinRule {
+    /// Creates a string slice from this `JoinRule`.
+    pub fn as_str(&self) -> &str {
+        self.as_ref()
+    }
+}
